#ifndef INC_DRAWER
#define INC_DRAWER

/**************************************************************
*
*                DRAWER.HPP
*
**************************************************************/

#include <notimtab.h> 
 
#define MAX_NOTE_HEIGHT 127

#define HEADLINE_DIVIDER 3 /* headl.height = syst.dist./HEADLINE_DIVIDER */

/*#define HEADLINE_HEIGHT 12    [points] */
#define FOOTLINE_HEIGHT  8   /* [points] */
#define INDEX_HEIGHT     8   /* [points] */
#define TRACK_HEIGHT     8   /* [points] */

/*** possible values for page type ***/

#define NO_TYPE    0x00  /* no valid type */
#define MULTIPLE   0x01  /* one or more whole note systems fit onto this page */
#define PRECEEDING 0x02  /* the tail of the system is on a succeeding page */
#define SUCCEEDING 0x04  /* the head of the system is on a preceeding page */

#pragma pack(1)
typedef struct 
{
	char number_of_systems ;           /* on this page */
	char type ;                        /* see above */
	int first_track, last_track ;      /* to be drawn for this page */
	TIME min_time ;                    /* in ticks */
} 
PAGE_DESCRIPTOR ;
#pragma pack()

#define MAX_PAGES   200

typedef struct 
{
#if defined (__PUREC__)
	/*** init only data ***/
	int handle ;               /* of VDI workstation */
	Awindow *obj_wi ;          /* window of GEM-object to be drawn */
	int obj ;                  /* index of GEM-object to be drawn */
	int width, height ;        /* of GEM-object */
#endif
	char *filename ;           /* of MIDI file */
	Awindow *params_wi ;       /* related object instances */
	Awindow *filter_wi ;       /* for access to their hidden data */
#if defined (__PUREC__)
	Awindow *info_wi ;     
	int ntrks ;                /* number of tracks to be treated */
#endif

	/*** read/write data ***/
	int font_id ;
	int current_page ;                 /* number of page that shall be displayed */
	int npgs ;                         /* number of pages with valid layout */
	PAGE_DESCRIPTOR page[MAX_PAGES] ;  /* drawing layout for all pages */
	int x_min, x_max, y_min, y_max ;   /* maximum area allowed for whole drawing */
	int x_min_systems, x_max_systems,  /* same for drawing note systems */
	    y_min_systems_0,	              /* (only on page 0) */
	    y_min_systems, y_max_systems ;
	float dy_system, dy_track ; 
	float dy_note, dy_line ;            /* y-distances */
	float dx_bars ;                     /* x-distance */
	float beats_per_system ;            /* quarter beats */
	int bars_per_system ;
	char bar_divider ;
	TIME time_per_system ;              /* in ticks per system */
} 
DRAWER ;

/*** page selecting mode for select_page() ***/

typedef enum {first, last, next, previous, same} SELECT_MODE ;

/*** init data for drawer constructor ***/

#if defined (__PUREC__)
typedef struct 
{
	CICONBLK *icon ;
	char *filename ;
	int handle ;
	Awindow *obj_wi ;
	int obj ;
	int width ;
	int height ;
	Awindow *params_window, *filter_window, *info_window ;
} 
DRAWER_INIT ;

/*******************************************************************
*/
	Awindow *DRAWER_constructor(DRAWER_INIT *) ;
/*	
*  Constructor of the DRAWER object. 
* 
* INPUT:   init values, see above
* 
* OUTPUT:  drawer icon on screen 
* 
* RETURN:  errors: NULL or -if successfull- ACS-window pointer,
*          which will be used as handle for the object instance
* 
*******************************************************************/

/*******************************************************************
*/
	void DRAWER_destructor(Awindow *) ;
	
/* Destructor of the DRAWER object. 
* 
* INPUT:   *window:  ACS-window to destruct
* 
*******************************************************************/
#endif

/*******************************************************************
*/
	void draw_page(
		int handle, 		/* VDI worksatation handle */
		Awindow *window, 	/* data of affected drawer instance */
        int x, 				/* x-offset of drawing */
        int y, 				/* y-offset of drawing */
        int *points, 		/* 2 clipping points */
        int zoom, 			/* zooming factor */
        int page			/* page number */
    ) ;               
/*
* OUTPUT:  drawing on VDI workstation
* 
*******************************************************************/

#if defined (__PUREC__)
/*******************************************************************
*/
	void select_page(Awindow *wi, SELECT_MODE sm) ;
	
/* Adjusts the page number to the desired one
*  and draws the corresponding page.
* 
* INPUT:   window: all data of the affected drawer instance
*          sm:     SELECT_MODE, see above
* 
* OUTPUT:  d->current_page: updated current page number
*                           according sm
*          redrawn drawer window
*          redrawn note systems
* 
*******************************************************************/
#endif

/*******************************************************************
*/
	int page_layouter(
		int handle, 		/* VDI worksatation handle */
		int width, 			/* width of pages to fit drawing */
		int height, 		/* height ... */
		Awindow *window		/* instance */
	) ;
	
/* Calculates the layout of all pages. The number
*  of pages depends on the current parameters.
*  The layouter only needs to be called when parameters have
*  changed, thus CPU time can be saved (i.e. the layouter 
*  should not always be called before drawing).
* 
* OUTPUT:  (d->x_min/d->y_min) and (d->x_max/d->y_max) are border
*          points of the allowed drawing area (allowed by the 
*          parameters object).
*          (d->x_min_systems/d->y_min_systems) and 
*          (d->x_max_systems/d->y_max_systems) are border
*          points of the drawing area for note systems 
*          (without headline, indeces).
*          d->npgs:             number of pages layouted
*          d->beats_per_system: beats_per_system
*          d->time_per_system:  time per system in [ticks] 
*          d->bars_per_system:  bars_per_system
*          d->bar_divider:      sub-bars per bar
*          d->dx_bars:          x-distance between bars
*          d->dy_system:        y-distance between different systems
*          d->dy_track:         y-distance between different tracks
*          d->dy_line:          y-distance between note lines
*          d->dy_note:          y-distance between notes
*          d->font_id:          ID of GDOS font
*          d->page[0..n]:       correctly updated
* 
* RETURN:  
*/
			#define LAYOUT_ERR -1  
			#define LAYOUT_GOOD 1  
/* 
*******************************************************************/

#if defined (__PUREC__)
/*******************************************************************
*/
	void reset_layout(Awindow *window) ;
	
/* Calls the "page_layouter" with the screen workstation's
*  maximum possible width and height.
* 
* INPUT:   window:       affected drawer instance
* 
* OUTPUT:  see "page_layouter"
* 
*******************************************************************/

/*******************************************************************
*/
	void redraw(Awindow *wi) ;
	
/* Causes a new layouting with current parameters
*  and a succeeding redrawing.
* 
* INPUT:   *wi: drawer window instance
* 
* OUTPUT:  - updated drawer object data, see "page_layouter"
*          - redrawn note systems on screen
* 
*******************************************************************/

/*******************************************************************
*/
	int get_first_page(Awindow *window) ;
	int get_last_page(Awindow *window) ;
	int get_current_page(Awindow *window) ;
	
/* Access procedures to the drawer object data. 
* 
* INPUT:   *wi: drawer window instance with data to be updated
* 
* RETURN:  page number of first/last displayable resp. currently
*          displayed page
* 
*******************************************************************/
#endif

#endif /* include blocker */