#ifndef INC_INFO
#define INC_INFO

/**************************************************************
*
*                INFO.HPP
*
**************************************************************/

#if defined (__PUREC__)

/*** init values for constructor ***/

typedef struct 
{
	CICONBLK *icon ;
	char *filename ;            /* for icon text and info line */
	unsigned char *RAM_file ;   /* pointer to MIDI file */
	long filesize ;             /* size of original MIDI file */
} 
INFO_INIT ;


/*******************************************************************
*/
	Awindow *INFO_constructor(INFO_INIT *) ;
/*
* constructor of the INFO object. It
* constructs an object instance of the INFO object containing
* ACS object and own data instances.
* 
* OUTPUT:  info window icon placed on screen,
*          header chunk data out of MIDI file entered into 
*          window work object
* RETURN:  errors: NULL or -if successfull- ACS-window pointer,
*          which will be used as handle for the object instance
* 
*******************************************************************/

/*******************************************************************
*/
	void INFO_destructor(Awindow *) ;
/*
* "INFO_destructor" is the destructor of the INFO object. It
* frees all memory used by ACS and own data instances.
* 
*******************************************************************/

/*******************************************************************
*/
	void set_transformed_size(Awindow *window, long transformed_size) ;
/* 
* INPUT:   window:            pointer to the own window instance
*          transformed_size:  shall be entered into GEM-object
* OUTPUT:  refreshed GEM-object 
* 
*******************************************************************/

/*******************************************************************
*/
	long get_file_size(Awindow *wi) ;
/* 
* INPUT:   window:            pointer to the own window instance
* RETURN:  file size in KByte 
* 
*******************************************************************/

#endif /* __PUREC__ */

/*******************************************************************
*/
	unsigned int get_number_of_tracks(Awindow *) ;
/* 
* INPUT:   window:      pointer to the own window instance
* RETURN:  number of tracks in MIDI file
* 
*******************************************************************/

/*******************************************************************
*/ 
	int get_ticks_per_beat(Awindow *window) ;
/* 
* INPUT:   window:  pointer to own window instance
* RETURN:  ticks per quarter in MIDI file
* 
*******************************************************************/

/*******************************************************************
*/
	int get_SMPTE(Awindow *window) ;
/* 
* INPUT:   window:  pointer to the window to serve
* RETURN:  0:       (FALSE) if "ticks per quarter" format
*          1:       (TRUE) if SMPTE format
* 
*******************************************************************/

#endif /* include blocker */