/**************************************************************
*
*                GRAPHICS.H
*
**************************************************************/

void
/*****************/
draw_background /*
******************/
(
	int handle, 	/* VDI workstation handle */
	int *points,	/* points[0]:     x-value of 1. corner
   					   points[1]:     y-value of 1. corner
	   				   points[2]:     x-value of 2. corner
		   			   points[3]:     y-value of 2. corner */
	int style, 		/* fill style */
	int color		/* fill	color */
) ;

void
/***********/
draw_note /*
************/
(
	int handle, 	/* VDI workstation handle */
	int *points,	/* points[0]:     x-value of 1. corner
					   points[1]:     y-value of 1. corner
					   points[2]:     x-value of 2. corner
					   points[3]:     y-value of 2. corner */
	int type,       /* see below */
	int body_style, 	/* fill style body */
	int body_color,		/* fill	color body */
	int end_style, 		/* fill style ends */
	int end_color		/* fill	color ends */
) ;

/******** note type is a set of the following attributes *****/

#define HEAD_LINE      0x0001   /* note head marked with a line */
#define TAIL_LINE      0x0002   /* note tail marked with a line */
#define HEAD_TRI       0x0004   /* note head marked with a triangle */
#define TAIL_TRI       0x0008   /* note tail marked with a triangle */
#define BODY_RECT      0x0010   /* note body is a rectangle */
#define BODY_ELLIP     0x0020   /* note body is an ellipse */
#define HEAD_DOT       0x0040   /* note head marked with something round */
#define TAIL_DOT       0x0080   /* note tail marked with something round */
#define BODY_TRI       0x0100   /* note body is a triangle */
#define HEAD_CUT       0x1000   /* points[0] in middle of note body */
#define TAIL_CUT       0x2000   /* points[2] in middle of note body */

/* other attributes may follow ... */


typedef enum {behind, between} MARK_MODE ;
#define INVALID_DX 0x7FFF	/* would be outside screen either */
#define INVALID_DY 0x7FFF

void
/************/
draw_lines /*
*************/
(
	int handle, 			/* VDI workstation handle */
	char number,			/* number of lines to be drawn */
	char first_marked, 		/* first line with special marking */
	char d_marked, 			/* special marking each d_marked lines */
	MARK_MODE mode, 		/* where to place rectangle marks */
	int styles[12], 		/* styles to be used after a special line */
	int colors[12], 		/* colors to be used after a special line */
	char first_number,      /* number (text) for first special line */
	int number_dots,		/* of special line, no dots if -1 */
	int dx_text, 			/* text (number) offset from x_start on */
	                        /* if INVALID_DX, no text is drawn      */
	int dy_text,			/* text (number) offset from y_start on */
	                        /* if INVALID_DY, no text is drawn      */
	int x_start, 			/* of first line */
	int y_start,			/* of first line */
	int x_end, 				/* of first line */
	int y_end,				/* of first_line */
	float dx, 				/* distance of succeeding lines */
	float dy				/* distance of succeeding lines */
) ; 


/*** macros for converting 8 bits and 5 bits  ***/
/*** color intensities with correct rounding. ***/
#define eight_to_five_bits(x) ( (x+0x4) >> 3 )
#define five_to_eight_bits(x) ( x << 3 )

/* 5 bits red, 5 bits green, 5 bits blue */
/* least significant is red */

#define RGB_RED   0x001F
#define RGB_GREEN 0x03E0
#define RGB_BLUE  0x7C00

/* VDI delivers 0..1000, I use 5 bit (0..255) color intensities */ 
#define thousand_to_5bit(x) ( (int)((float)(x) * 31/1000 + 0.5) )

/* actual number of colors is obtained from ACS */
#define MAX_COLORS 256


void
/****************/
init_rgb_table /* must be called before index_to_rgb and rgb_to_index!
*****************/
(int handle) ; /* normally the screen handle */

/******************/
int rgb_to_index /* 15-bit (5+5+5) rgb value to VDI color index
*******************/
(int rgb) ;

/******************/
int index_to_rgb /* VDI color index to 15-bit (5+5+5) rgb value
*******************/
(int index) ;

