#ifndef INC_NOTIMTAB
#define INC_NOTIMTAB

#include "..\include\servimem.h"
#include "midi.h"

/**************************************************************
*
*                NOTIMTAB.H
*
**************************************************************/

/******* access to note time table via the following structure *************/

typedef event NOTE ;		/* 8 Bits */
#define _ON_	0x80		/* internal representation of "note on" */
typedef __int32 TIME ;


/*---------------------------------------------- 
The following structure must be packed.
The note time table memory can be allocated 
as estimated in advance from the MIDI file
size multiplied by a minimum fixed number. 
For this easy approach to work, the note 
time table element size 
must be packed to its minimum possible size. 
------------------------------------------------*/

#pragma pack(1)
typedef struct 
{
	TIME time ;              /* absolute time of event (element) */
	__int16 reference ;      /* pointer to corresponding note on/off event */
	unsigned char dynamic ;  /* note on dynamic or note off dynamic */
	NOTE note ;              /* bit7 = 0 note off; bit7 = 1 note on */
	unsigned char channel ;  /* origination channel of event */ 
} 
/***********************/
NOTE_TIME_TABLE_ELEMENT ;
/***********************/
#pragma pack()


/********************************************************************
*/
	unsigned int fill_note_time_table
	(
		unsigned char           *track_address,      /* IN: pointer to a track 
                                                                    in a MIDI file */
		__int32                 track_length,        /* IN: in bytes */
		NOTE_TIME_TABLE_ELEMENT *first_element,      /* OUT: note time table */
		__int32                 *elements_generated, /* OUT: elems. filled into 
                                                                     note time table */
		unsigned __int16 *channels,                  /* OUT: mask indicating 
                                                                     non-empty channels */
		NOTE *min_note,                              /* OUT: lowest and highest */
		NOTE *max_note,                              /*      note of the track  */
		char *trackname,                             /* OUT: track name */
		unsigned int  max_text_length                /* IN: max. length of track name */
	) ;
/*
*  Transforms the data of a 
*  MIDI standard file into a fast access data structure for 
*  further processing. 
* 
*  RETURN: 
*/
	#define note_time_table_filled         10
	#define wrong_event_found              11
	#define data_without_status_given      12
	#define next_data_overflow             13
	#define no_var_length_number           14
/* 
********************************************************************/


/*******************************************************************
*/
	NOTE_TIME_TABLE_ELEMENT *get_element
	(
		NOTE_TIME_TABLE_ELEMENT *first_element, /* IN: start position */
		unsigned __int32        number,         /* IN: number of elements after
		                                               first element to inspect */
		TIME                    time            /* IN: nominal time of element */
	) ;
/*
* Searches the one element in a note time table
* which possesses a time that is as near as possible 
* to the input time and higher than the input time.
* The first element with this fewest possible or equal time
* is returned if more elements have the same time.
* 
* RETURN:  pointer to the element found, or NULL (if only 
*          elements with lower times exist in the specified range)
* 
*******************************************************************/	

#endif // include blocker